@@ -3,6 +3,7 @@
 # 
 # @arguments data frame
 # @arguments any additional aesthetic mappings (do not use x and y)
+# @arguments default point colour
 # @keyword hplot
 #X plotmatrix(mtcars[, 1:3])
 #X plotmatrix(mtcars[, 1:3]) + geom_smooth(method="lm")
@@ -31,7 +32,7 @@ plotmatrix <- function(data, mapping=aes(), colour="black") {
       x = data[, i]
     )
   }))
-  mapping <- defaults(mapping, aes_string(x="x", y="y"))
+  mapping <- plyr::defaults(mapping, aes_string(x="x", y="y"))
   class(mapping) <- "uneval"
 
   ggplot(all, mapping) + facet_grid(xvar ~ yvar, scales = "free") +
