@@ -12,7 +12,7 @@
 # }
 #
 # @arguments plot object
-# @argument object to add
+# @arguments object to add
 # @seealso \code{\link{set_last_plot}}, \code{\link{ggplot}}
 # @keyword internal
 # @alias \%+\%
@@ -22,12 +22,12 @@
   if (is.data.frame(object)) {
     p$data <- object
   } else if (inherits(object, "options")) {
-    object$labels <- defaults(object$labels, p$options$labels)
-    p$options <- defaults(object, p$options)
+    object$labels <- plyr::defaults(object$labels, p$options$labels)
+    p$options <- plyr::defaults(object, p$options)
   } else if(inherits(object, "labels")) {
       p <- update_labels(p, object)
   } else if(inherits(object, "uneval")) {
-      p$mapping <- defaults(object, p$mapping)
+      p$mapping <- plyr::defaults(object, p$mapping)
       
       labels <- lapply(object, deparse)
       names(labels) <- names(object)
@@ -45,8 +45,8 @@
         mapping <- as.list(as.character(object$mapping))
         default <- as.list(as.character(object$stat$default_aes()))
         
-        new_labels <- defaults(mapping, default)
-        p$options$labels <- defaults(p$options$labels, new_labels)
+        new_labels <- plyr::defaults(mapping, default)
+        p$options$labels <- plyr::defaults(p$options$labels, new_labels)
         p
       },
       coord = {
