@@ -16,11 +16,12 @@ StatContour <- proto(Stat, {
     }
     
     z <- tapply(data$z, data[c("x", "y")], identity)
-    cl <- contourLines(x = unique(data$x), y = unique(data$y), z = z, 
+    cl <- contourLines(
+      x = sort(unique(data$x)), y = sort(unique(data$y)), z = z, 
       levels = breaks)  
     cl <- lapply(cl, as.data.frame)
     
-    contour_df <- rbind.fill(cl)
+    contour_df <- plyr::rbind.fill(cl)
     contour_df$piece <- rep(seq_along(cl), sapply(cl, nrow))
     contour_df$group <- paste(data$group[1], contour_df$piece, sep = "-")
     contour_df
